{% extends "epic/base_layout.html" %}
{% load staticfiles %}
{% load crispy_forms_tags %}

{% block extrahead %}
{{ block.super }}
{{ inv_form.media }}	<!-- for django-bootstrap3-datetimepicker -->
{{ item_form.media }}
<script src="{% static "epic/js/editing.js" %}"></script>
{% endblock extrahead %}

{% block content %}
{{ block.super }}

<form method="POST" enctype="multipart/form-data">

<div class="form-horizontal">
  {% crispy inv_form %}
</div>

{% crispy item_form %}

<div class="form-actions">
  <input type="submit" name="save" value="Save" class="btn btn-primary">
  <input type="submit" name="save-and-zero" value="Save & Zero-out"
	  class="btn btn-secondary"
	  title="Save this inventory and create zero-quantity entries for parts not already listed.">
  <input type="submit" name="save-and-done" value="Save & Done"
	 class="btn btn-default">
  <a href="{{ cancel_url  }}" name="cancel" class="btn btn-default">Cancel</a>
</div>
</form>

<br>

{% endblock content %}
