{% extends "base_epic.html" %}
{% load staticfiles %}

{% block extrahead %}
<link rel="stylesheet" type="text/css"
      href="{% static "epic/css/epic.css" %}" />
{% if DEVELOPMENT_SITE %}
<!-- Make easy to see that you're using the development site... -->
<style>body { background-color: #f0fff0; background-image: none }</style>
{% endif %}
{% endblock extrahead %}

{% block content %}
<legend>
  <div class="row clearfix">
    <div class="pull-left">
    {{ breadcrumb|safe }}
    </div>
    <div class="col-md-4 pull-right">
      <form action="{% url 'epic:search_results' %}" method="GET">
	<div class="input-group">
	  <input class="form-control"
		 placeholder="Search for part or transaction&hellip;"
		 name="q">
	  <span class="input-group-btn">
	    <button type="submit" class="btn btn-default">
	      <i class="glyphicon glyphicon-search"></i>
	    </button>
	  </span>
	</div>
      </form>
      <div style="height:0.4ex"></div>
    </div>
  </div>
</legend>

<div class="row">
  <div class="col-md-12 clearfix">
    <div class="pull-left">
      {% block buttons %}
      {% endblock buttons %}
    </div>
    <div class="pull-right">
      <a class="btn btn-default" href="{% url 'epic:part_list' %}">
	Parts</a>
      <a class="btn btn-default" href="{% url 'epic:order_list' %}">
	Orders</a>
      <a class="btn btn-default" href="{% url 'epic:ship_list' %}">
	Shipments</a>
      <a class="btn btn-default" href="{% url 'epic:warehouse_list' %}">
	Warehouses</a>
      <a class="btn btn-default" href="{% url 'epic:vendor_list' %}">
	Vendors</a>
    </div>
  </div>
  <br>
</div>
{% endblock content %}
